#
# spec file for package votca-tools
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2013-2020 Christoph Junghans
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           votca-tools
Version:        1.6.4
Release:        bp154.2.51
%define         uversion %{version}
%define         sover 6
Summary:        VOTCA tools library
License:        Apache-2.0
Group:          Productivity/Scientific/Chemistry
URL:            http://www.votca.org
Source0:        https://github.com/votca/tools/archive/v%{uversion}.tar.gz#/%{name}-%{uversion}.tar.gz

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  cmake
BuildRequires:  eigen3-devel
BuildRequires:  fftw3-devel
BuildRequires:  gcc-c++
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_test-devel
BuildRequires:  libexpat-devel
BuildRequires:  pkg-config
Conflicts:      libvotca_tools5 < %{version}

%description
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

%package -n libvotca_tools%sover
Summary:        VOTCA tools library
Group:          System/Libraries

%description -n libvotca_tools%sover
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

This package contains the basic tools library of VOTCA package.

%package devel
Summary:        Development headers and libraries for votca-tools
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       eigen3-devel
Requires:       fftw3-devel
Requires:       libexpat-devel
Requires:       libvotca_tools%sover = %{version}

%description devel
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

This package contains development headers and libraries for votca-tools.

%prep
%setup -n tools-%{uversion} -q

# Avoid unnecessary rebuilds of the package
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M:%%S')
sed -i -e "s/__DATE__/\"$FAKE_BUILDDATE\"/" -e "s/__TIME__/\"$FAKE_BUILDTIME\"/" src/libtools/version.cc

%build
%{cmake} -DWITH_RC_FILES=OFF -DCMAKE_SKIP_RPATH=OFF -DENABLE_TESTING=ON
%cmake_build

%install
%cmake_install
sed -i '1s@env @@' %{buildroot}/%{_bindir}/votca_compare

%check
%ctest

%files
%{_bindir}/votca_*
%{_mandir}/man1/*
%{_mandir}/man7/*

%post -n libvotca_tools%sover -p /sbin/ldconfig
%postun -n libvotca_tools%sover -p /sbin/ldconfig

%files -n libvotca_tools%sover
%doc NOTICE README.md CHANGELOG.md
%license LICENSE
%{_libdir}/libvotca_tools.so.%{sover}

%files devel
%{_includedir}/votca/
%{_libdir}/libvotca_tools.so
%{_libdir}/cmake/VOTCA_TOOLS

%changelog
* Tue Jan 12 2021 Christoph Junghans <junghans@votca.org>
- Update to 1.6.4
  - no changes
* Wed Dec  9 2020 Christoph Junghans <junghans@votca.org>
- Update to 1.6.3
  - switch to ghcr.io for CI ([gh#votca/tools#297])
  - use master .clang-format in format action
    ([gh#votca/tools#304], [gh#votca/tools#307])
  - strip windows line endings in readers ([gh#votca/tools#309])
* Sat Aug 22 2020 Christoph Junghans <junghans@votca.org>
- Update to 1.6.2
  - format code with clang-10 ([gh#votca/tools#278])
  - move CI to GitHub Actions ([gh#votca/tools#280],
    [gh#votca/tools#285], [gh#votca/tools#287])
  - fix build with mkl ([gh#votca/tools#283])
* Mon Jun 22 2020 Christoph Junghans <junghans@votca.org>
- Update to 1.6.1
  - fix build with mkl ([gh#votca/tools#229])
  - fix build with non-system libfftw ([gh#votca/tools#234])
  - fix CI on Ubuntu-20.04 ([gh#votca/tools#237])
  - fix bug related to calling c abs instead of c++ fabs
    ([gh#votca/tools#248])
  - updated floating point comparison in akimaspline.h
    ([gh#votca/tools#248])
  - fix compile error in structure parameters by adding hash
    function ([gh#votca/tools#248])
* Mon Jun 15 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Move the miscellaneous manpages from the library package to the
  main package. SLPP disallows non-versioned files in the
  shared-library package as it makes them non-parallel installable
  to newer versions. Additionally, the man page does not provide
  information of pure library users.
- Have the main package conflict with the old library package
  (libvotca_tools5) that contained the man page.
* Sat Apr 18 2020 Christoph Junghans <junghans@votca.org>
- Update to 1.6
  * fix clang-10 warnings ([gh#votca/tools#217])
  * clean up VOTCARC.* ([gh#votca/tools#220])
  * fix exported target with mkl ([gh#votca/tools#223],
  * [gh#votca/tools#224])
* Mon Feb 10 2020 Christoph Junghans <junghans@votca.org>
- Update to 1.6_rc2
  * fix inheritance bug in cmake files ([gh#votca/tools#197])
  * fix bug in table class ([gh#votca/tools#196])
  * fix build on 32-bit archs ([gh#votca/tools#199])
  * remove old doxygen target ([gh#votca/tools#211])
* Thu Dec  5 2019 Christoph Junghans <junghans@votca.org>
- Update to 1.6_rc1
  * replaced fftw with Eigen3 fft
  * replaced random with std::random implementation
  * added many unit tests
  * formated code with clang-format
  * major cmake refactor
* Thu Nov 21 2019 Christoph Junghans <junghans@votca.org>
- Upgrade to 1.5.1
  * switch votca_compare to python3
  * more clear error message for xmlreader
  * fix build on CentOs7
* Thu Sep 26 2019 Christoph Junghans <junghans@votca.org>
- Fix build on i586
* Tue Mar 19 2019 Christoph Junghans <junghans@votca.org>
- Fix build with boost-1.69
* Thu Jan 31 2019 Christoph Junghans <junghans@votca.org>
- Upgrade to 1.5
  * histogramnew: refactor to fix memory lead
  * added unit testing
  * Eigen added as a dependency
  * removed GSL dependency
  * details: https://github.com/votca/tools/blob/master/CHANGELOG.md
* Sun Sep  3 2017 junghans@votca.org
- Upgrade to 1.4.1
  * fix pkg-config files
  * details: https://github.com/votca/csg/blob/master/CHANGELOG.md
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Mon Oct 31 2016 jengelh@inai.de
- RPM group fixing
- Trim filler words from description
* Sat Oct 29 2016 junghans@votca.org
- Upgrade to 1.4
  * added support for boost-1.62
  * details: https://github.com/votca/csg/blob/master/CHANGELOG.md
* Tue Sep 27 2016 junghans@votca.org
- Upgrade to 1.4_rc1
  * added support for mkl as gsl replacement
  * details: https://github.com/votca/csg/blob/master/CHANGELOG.md
* Fri Aug 19 2016 junghans@votca.org
- Upgrade to 1.3
  * fix bug in histogram class
  * details: https://github.com/votca/csg/blob/master/CHANGELOG.md
* Fri Jan 15 2016 junghans@votca.org
- Upgrade to 1.3
  * details: https://github.com/votca/csg/blob/master/CHANGELOG.md
* Thu Oct  8 2015 junghans@votca.org
- Upgrade to 1.3_rc1
  * details: https://github.com/votca/csg/blob/master/CHANGELOG.md
* Fri Sep  5 2014 junghans@votca.org
- Upgrade to 1.2.4
  * support for Boost 1.53
  * drop votca-tools-1.2.3-boost-1.53.patch: merged upstream
* Thu Nov 28 2013 junghans@votca.org
- implemented suggestions by mvyskocil from request 207986
* Fri Nov 22 2013 junghans@votca.org
- clean up suggested by saschpe in request 207134
* Wed Oct 30 2013 junghans@votca.org
- Upgrade to 1.2.3
  * rename package to libvotca_tools2
  * Add votca-tools-1.2.3-boost-1.53.patch: build with boost 1.53
  * create manpage using txt2tags
* Sun Aug 28 2011 kkaempf@suse.com
- Upgrade to 1.2.1
  * fixed soname of libs to .so.2
  - rename package to libvotca2
  * improved cmake checks and error messages
  * fixed pkg-config file
- Version 1.2 (SuperDoris)
  * changed buildsystem to cmake
  * added database class through sqlite3
- Version 1.1.2
  * fixed head of votca-tools manpage
* Thu Mar  3 2011 kkaempf@novell.com
- Upgrade to 1.1.1
  See http://code.google.com/p/votca/issues/list?can=1&q=Milestone%%3DRelease1.1
* Mon Dec  6 2010 kkaempf@novell.com
- Initial version 1.0.1 for openSUSE
- remove unused copies of boost and expat from tarball
  (incompatible license)
- fix packagename to follow shared lib name rule
  (incomplete, rpmlintrc added for override)
* Tue Nov 30 2010 junghans@votca.org
- Minor clean up
* Thu Nov 25 2010 jussilehtola@fedoraproject.org
- First release.
